Frozen-Flask
============

.. image:: https://img.shields.io/pypi/v/Frozen-Flask.svg?maxAge=2592000
   :target: https://pypi.python.org/pypi/Frozen-Flask

Freezes a Flask application into a set of static files. The result can be hosted
without any server-side software other than a traditional web server.

See documentation: https://pythonhosted.org/Frozen-Flask/

Build Status
------------

.. image:: https://github.com/Frozen-Flask/Frozen-Flask/workflows/CI/badge.svg?branch=master
   :target: https://github.com/Frozen-Flask/Frozen-Flask/actions

Contributing
------------

* Fork the upstream repository and clone your fork
* Create a feature branch for the thing you want to work on
* Create a virtual environment and activate it
* Run ``pip install -e .`` to install dependencies
* Use ``tox`` or ``python -m flask_frozen.tests`` to run tests
* Do your changes, make sure tests pass
* Send a Pull Request to the upstream repository

Maintainers
-----------

- `@honzajavorek <https://github.com/honzajavorek>`__ - Dedicates around an hour per week or less, which means just occasional PR reviews, releases and minor fixes.
- `@tswast <https://github.com/tswast>`__ - Occasional `Deus ex machina <https://en.wikipedia.org/wiki/Deus_ex_machina>`__.
- `@SimonSapin <https://github.com/SimonSapin>`__ - Inactive, but has his picture in our Hall of Fame for creating the project.

If you want to join the list, you can generally qualify yourself by contributing to the project with a few Pull Requests (don't forget tests).

License
-------

Frozen-Flask uses a BSD 3-clause license. See LICENSE_.

.. _LICENSE: LICENSE
